<?php
namespace Pinpoint\LogoManager\Controller\Adminhtml\Logo;

use Magento\Backend\App\Action;
use Pinpoint\LogoManager\Model\Page;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\NoSuchEntityException;

/**
 * Class Save
 * @package Pinpoint\LogoManager\Controller\Adminhtml\Logo
 */
class Save extends \Magento\Backend\App\Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_LogoManager::addedit';

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var \Pinpoint\LogoManager\Model\LogoRepository
     */
    protected $logoRepository;


    protected $logoFactory;

    public function __construct(
        Action\Context $context,
        DataPersistorInterface $dataPersistor,
        \Pinpoint\LogoManager\Model\LogoRepository $logoRepository,
        \Pinpoint\LogoManager\Model\LogoFactory $logoFactory
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->logoRepository = $logoRepository;
        $this->logoFactory = $logoFactory;

        parent::__construct($context);
    }

    /**
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_LogoManager::logo_manager');
    }

    /**
     * Save action
     *
     * @SuppressWarnings(PHPMD.CyclomaticComplexity)
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($data) {
            if (isset($data['is_active']) && $data['is_active'] === 'true') {
                $data['is_active'] = \Pinpoint\LogoManager\Model\Logo::STATUS_ENABLED;
            }
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            $model = $this->logoFactory->create();
            $id = $this->getRequest()->getParam('id');

            if ($id) {
                try {
                    $model = $this->logoRepository->getById($id);
                } catch (NoSuchEntityException $ex) {
                    unset($ex);
                }
            }

            if (isset($data['logo'])) {
                $data['logo'] = $data['logo'][0]['file'];
            }

            $model->setData($data);

            try {
                $model->save();
                $this->messageManager->addSuccess(__('The logo has been saved.'));
                $this->dataPersistor->clear('pinpoint_logomanager_logo');

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', ['id' => $model->getId(), '_current' => true]);
                }

                return $resultRedirect->setPath('*/*/list');
            } catch (LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addException($e, __('Something went wrong while saving the Logo.'));
            }

            $this->dataPersistor->set('pinpoint_logomanager_logo', $data);
            return $resultRedirect->setPath('*/*/edit', ['id' => $this->getRequest()->getParam('id')]);
        }
        return $resultRedirect->setPath('*/*/list');
    }    
}
